@@ -1,7 +1,9 @@
 #[allow(dead_code)]
 pub use crate::{arel, ArelAble};
-pub use sqlx::{self, Row};
+#[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+pub use crate::collectors::row::Row as ArelRow;
 
+pub use sqlx::{self, Row as SqlxRow};
 #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
 pub use sqlx::any;
 pub use async_trait;
