@@ -1,5 +1,5 @@
 use std::ops::{Bound, RangeBounds};
-use serde_json::{json, Value as Json};
+use serde_json::{Value as Json};
 use std::marker::PhantomData;
 use crate::statements::StatementAble;
 use crate::collectors::Sql;
